@@ -181,7 +181,7 @@ Trim.prototype.pickEntity = function(event, preview) {
         }
 
         // unsupported entity chosen:
-        if (!this.isSupportedTrimEntity(entity)) {
+        if (!Trim.isSupportedTrimEntity(entity)) {
             this.trimEntity = undefined;
             if (preview) {
                 this.updatePreview();
@@ -228,7 +228,7 @@ Trim.prototype.isSupportedLimitingShape = function(shape) {
            (RPolyline.hasProxy() && isPolylineShape(shape));
 };
 
-Trim.prototype.isSupportedTrimEntity = function(entity) {
+Trim.isSupportedTrimEntity = function(entity) {
     return isLineBasedEntity(entity) ||
            isArcEntity(entity) ||
            isCircleEntity(entity) ||
@@ -297,6 +297,7 @@ Trim.trim = function(op, limitingEntity, limitingClickPos, trimEntity, trimClick
         return false;
     }
 
+
     var trimShape = trimEntity.castToShape();
     if (isNull(trimShape)) {
         return false;
@@ -321,6 +322,11 @@ Trim.trim = function(op, limitingEntity, limitingClickPos, trimEntity, trimClick
         }
     }
 
+    if (trimBoth && isClosedPolylineEntity(limitingEntity) && !samePolyline) {
+        // no trimming between two different closed polylines:
+        return false;
+    }
+
     var newShapes = Trim.trimShapes(trimShape, trimClickPos, limitingShape, limitingClickPos, trimBoth, samePolyline);
     if (newShapes.length===0) {
         return false;
